@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -623,7 +623,7 @@ QAction *ComposerWebEngine::action(ComposerWebEngineAction actionType) const
     case LastType:
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 QMap<QString, QString> ComposerWebEngine::localImages() const
